==> miniprogram-cdn-2.3.1.tgz: package/es/index.js <==
///<reference lib="es2015.core"/>
const COMPRESS_PREFIX = /*#__PURE__*/ "?basic=";
/**
 * 获取文件后缀
 * @param path 文件名
 */
export function isGif(path) {
    return path && path.toLowerCase().endsWith(".gif");
}
/**
 * URL预处理
 */
function replaceUrl(url, domainList, cdnSite) {
    if (typeof url !== "string") {
        console.error("invalid url<not string>:", url);
    }
    else {
        url = url.split(COMPRESS_PREFIX)[0];
        domainList.forEach(e => (url = url.replace(e, cdnSite)));
    }
    return url;
}
/**
 * 配置信息
 */
export const config = /*#__PURE__*/ {
    /**
     * 宽度, 默认2K屏
     */
    Width: 1440,
    /**
     * 屏幕高度, 默认2K屏幕
     */
    Height: 2560,
    /**
     * 图片质量1~100
     */
    Quality: 100,
    /**
     * 缩略图宽度
     */
    ThumbnailWidth: 138,
    /**
     * 缩略图宽度1~100
     */
    ThumbnailQuality: 1,
    /**
     * 代替换的域名列表
     */
    DomainList: [],
    /**
     * 图片处理CDN
     */
    ImageCDN: "",
    /**
     * 媒体流加速CDN
     */
    StreamCDN: "",
    isAndroid: false,
};
/**
 * 生成压缩URL
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
export function compress(option, cdnSite, domainList = []) {
    const url = cdnSite ? replaceUrl(option.url, domainList, cdnSite) : cdnSite;
    // //gif图不处理
    // if (ext === "gif") {
    //     return url;
    // }
    let param = "";
    if (option.width) {
        param += `_${option.width}w`;
    }
    if (option.height) {
        param += `_${option.height}h`;
    }
    if (option.quality && option.quality < 100) {
        param += `_${option.quality}q`;
    }
    if (option.progressive) {
        param += `_1pr`;
    }
    if (option.scaleType) {
        param += `_${option.scaleType}e`;
    }
    if (option.cut) {
        param += `_1c`;
    }
    if (option.ext) {
        param += option.ext;
    }
    return param ? url + COMPRESS_PREFIX + (option.larger ? "0l" : "1l") + param : url;
}
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
export function adaptiveImage(url) {
    return compress({
        url: url,
        width: config.Width,
        quality: config.Quality,
        progressive: config.Width > 800,
        ext: isGif(url) ? ".gif" : config.isAndroid ? ".webp" : ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 横屏自适应图像
 * @param url url of image
 */
export function adaptiveLandscapeImage(url) {
    const width = config.Width > config.Height ? config.Width : config.Height;
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            width: width,
            quality: config.Quality,
            progressive: width > 800,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 渐进式加载大图
 * @param url image URL
 */
export function progressiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            progressive: true,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
export function shareImage(url) {
    return compress({
        url: url,
        width: 500,
        height: 400,
        cut: true,
        scaleType: 1,
        quality: 75,
        larger: true,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 小尺寸缩略图
 * @param url 原url
 */
export function thumbnail(url) {
    return compress({
        url: url,
        width: config.ThumbnailWidth,
        quality: config.ThumbnailQuality,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 流媒体
 * @param url 原url
 */
export function streamCdn(url) {
    return config.StreamCDN ? replaceUrl(url, config.DomainList, config.StreamCDN) : url;
}

==> miniprogram-cdn-2.4.0.tgz: package/es/index.js <==
///<reference lib="es2015.core"/>
const COMPRESS_PREFIX = /*#__PURE__*/ "?basic=";
/**
 * 获取文件后缀
 * @param path 文件名
 */
export function isGif(path) {
    return path && path.toLowerCase().endsWith(".gif");
}
/**
 * URL预处理
 */
function replaceUrl(url, domainList, cdnSite) {
    if (typeof url !== "string") {
        console.error("invalid url<not string>:", url);
    }
    else {
        url = url.split(COMPRESS_PREFIX)[0];
        domainList.forEach(e => (url = url.replace(e, cdnSite)));
    }
    return url;
}
/**
 * 配置信息
 */
export const config = /*#__PURE__*/ {
    /**
     * 宽度, 默认2K屏
     */
    Width: 1440,
    /**
     * 屏幕高度, 默认2K屏幕
     */
    Height: 2560,
    /**
     * 图片质量1~100
     */
    Quality: 100,
    /**
     * 缩略图宽度
     */
    ThumbnailWidth: 138,
    /**
     * 缩略图宽度1~100
     */
    ThumbnailQuality: 1,
    /**
     * 代替换的域名列表
     */
    DomainList: [],
    /**
     * 图片处理CDN
     */
    ImageCDN: "",
    /**
     * 媒体流加速CDN
     */
    StreamCDN: "",
    isAndroid: false,
};
/**
 * 生成压缩URL
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
export function compress(option, cdnSite, domainList = []) {
    const url = cdnSite ? replaceUrl(option.url, domainList, cdnSite) : cdnSite;
    // //gif图不处理
    // if (ext === "gif") {
    //     return url;
    // }
    let param = "";
    if (option.width) {
        param += `_${option.width}w`;
    }
    if (option.height) {
        param += `_${option.height}h`;
    }
    if (option.quality && option.quality < 100) {
        param += `_${option.quality}q`;
    }
    if (option.progressive) {
        param += `_1pr`;
    }
    if (option.scaleType) {
        param += `_${option.scaleType}e`;
    }
    if (option.cut) {
        param += `_1c`;
    }
    if (option.ext) {
        param += option.ext;
    }
    return param ? url + COMPRESS_PREFIX + (option.larger ? "0l" : "1l") + param + (option.acceptraw ? '&p=acceptraw' : '') : url;
}
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
export function adaptiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            acceptraw: true,
            url: url,
            width: config.Width,
            quality: config.Quality,
            progressive: config.Width > 800,
            ext: isGif(url) ? ".gif" : config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 横屏自适应图像
 * @param url url of image
 */
export function adaptiveLandscapeImage(url) {
    const width = config.Width > config.Height ? config.Width : config.Height;
    return isGif(url)
        ? url // gif 不处理
        : compress({
            acceptraw: true,
            url: url,
            width: width,
            quality: config.Quality,
            progressive: width > 800,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 渐进式加载大图
 * @param url image URL
 */
export function progressiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            acceptraw: true,
            url: url,
            progressive: true,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
export function shareImage(url) {
    return compress({
        acceptraw: true,
        url: url,
        width: 500,
        height: 400,
        cut: true,
        scaleType: 1,
        quality: 75,
        larger: true,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 小尺寸缩略图
 * @param url 原url
 */
export function thumbnail(url) {
    return compress({
        acceptraw: true,
        url: url,
        width: config.ThumbnailWidth,
        quality: config.ThumbnailQuality,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 流媒体
 * @param url 原url
 */
export function streamCdn(url) {
    return config.StreamCDN ? replaceUrl(url, config.DomainList, config.StreamCDN) : url;
}
